Module: Lennarb
- Defined in:
- lib/lennarb.rb,
lib/lennarb/app.rb,
lib/lennarb/base.rb,
lib/lennarb/hooks.rb,
lib/lennarb/config.rb,
lib/lennarb/errors.rb,
lib/lennarb/logger.rb,
lib/lennarb/routes.rb,
lib/lennarb/helpers.rb,
lib/lennarb/request.rb,
lib/lennarb/version.rb,
lib/lennarb/response.rb,
lib/lennarb/constants.rb,
lib/lennarb/route_node.rb,
lib/lennarb/environment.rb,
lib/lennarb/request_handler.rb,
lib/lennarb/middleware_stack.rb,
lib/lennarb/parameter_filter.rb,
lib/lennarb/middleware/request_logger.rb
Overview
:nodoc:
Defined Under Namespace
Modules: Helpers, Hooks, Middleware Classes: App, Base, Config, Environment, Logger, MiddlewareStack, ParameterFilter, Request, RequestHandler, Response, RouteNode, Routes
Constant Summary collapse
- Error =
Base class for errors raised by Lennarb.
Class.new(StandardError)
- DuplicateRouteError =
Raised when merging routes would define the same HTTP method twice for the same path.
Class.new(StandardError)
- MissingEnvironmentVariable =
Raised when a mandatory configuration value has no environment variable set.
Class.new(StandardError)
- MissingCallable =
Raised when a configuration property is declared without something callable to compute it.
Class.new(StandardError)
- RoutesFrozenError =
Raised when a route is registered after the routes have been frozen.
Class.new(RuntimeError)
- VERSION =
:nodoc:
"1.5.1"- RACK_LENNA_APP =
The root app directory of the app.
"lennarb.app"- ENV_NAMES =
The current environment. Defaults to "development".
%w[LENNA_ENV APP_ENV RACK_ENV]- HTTP_METHODS =
The HTTP methods.
i[GET POST PUT PATCH DELETE HEAD OPTIONS]
- CONTENT_TYPE =
The HTTP status codes.
{HTML: "text/html", TEXT: "text/plain", JSON: "application/json"}
- NAMES =
The current environment. Defaults to "development".
i[development test production local]